@@ -10,10 +10,13 @@
 
 #include <QDateTime>
 #include <QObject>
+#include <qqmlregistration.h>
 
 class Formatter : public QObject
 {
     Q_OBJECT
+    QML_ELEMENT
+    QML_SINGLETON
 public:
     Q_INVOKABLE double convertTemp(qreal temperature, const QString &unit) const;
     Q_INVOKABLE QString formatTemperatureUnitDegrees(const QString &unit) const;
@@ -23,6 +26,8 @@ public:
     Q_INVOKABLE QString formatWindSpeed(qreal speed, const QString &unit) const;
 
     Q_INVOKABLE QString formatPressure(qreal pressure, const QString &unit) const;
+    Q_INVOKABLE QString formatPercent(qreal percentage) const;
+    Q_INVOKABLE QString formatDouble(qreal number) const;
 
     Q_INVOKABLE QString formatSunriseTime(QDateTime date, const QString &timeZone) const;
     Q_INVOKABLE QString formatPrecipitation(qreal precipitation, const QString &unit) const;
